==> haskell-ansi-terminal-1.0.2-102-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-terminal
version:              1.0.2
visibility:           public
id:                   ansi-terminal-1.0.2-D5qYwqv6rV8C8VJ5M6PJzO
key:                  ansi-terminal-1.0.2-D5qYwqv6rV8C8VJ5M6PJzO
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Simple ANSI terminal support
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.

category:             User Interfaces
abi:                  713bb43acfa48deb5d5c7906db2ca682
exposed:              True
exposed-modules:
    System.Console.ANSI, System.Console.ANSI.Codes,
    System.Console.ANSI.Types from ansi-terminal-types-0.11.5-yfu9gsm2DNJG8HNmJWdQG:System.Console.ANSI.Types

hidden-modules:       System.Console.ANSI.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ansi-terminal-1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ansi-terminal-1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ansi-terminal-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal
hs-libraries:         HSansi-terminal-1.0.2-D5qYwqv6rV8C8VJ5M6PJzO
depends:
    ansi-terminal-types-0.11.5-yfu9gsm2DNJG8HNmJWdQG base-4.17.2.1
    colour-2.3.6-D3OuYc0xuK09XFheGUPDon

haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-terminal-1.0.2-104-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-terminal
version:              1.0.2
visibility:           public
id:                   ansi-terminal-1.0.2-4YFJ3O2CGvXHeK0JwiwGsH
key:                  ansi-terminal-1.0.2-4YFJ3O2CGvXHeK0JwiwGsH
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Simple ANSI terminal support
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.

category:             User Interfaces
abi:                  6956f6fbfb78bcfa3ac324f8a1c76553
exposed:              True
exposed-modules:
    System.Console.ANSI, System.Console.ANSI.Codes,
    System.Console.ANSI.Types from ansi-terminal-types-0.11.5-BzqjqeGKAo35aChdQxZH3j:System.Console.ANSI.Types

hidden-modules:       System.Console.ANSI.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ansi-terminal-1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ansi-terminal-1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ansi-terminal-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal
hs-libraries:         HSansi-terminal-1.0.2-4YFJ3O2CGvXHeK0JwiwGsH
depends:
    ansi-terminal-types-0.11.5-BzqjqeGKAo35aChdQxZH3j base-4.17.2.1
    colour-2.3.6-JZ2xJEG7ktI3yz7roXpz0n

haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
